==> tau8n-1.8.0-b88-with-loader.tar.gz: upgrade.sh <==
#!/bin/sh

FW_VERSION_1="fw_version_1"
FW_VERSION_2="fw_version_2"

#echo 2 > /proc/sys/vm/overcommit_memory
#echo 100 > /proc/sys/vm/overcommit_ratio

echo "Start firmware upgrading"
echo "Start firmware upgrading" > /dev/console


setupgradestatus 1
if [ "$?" != "0" ]; then
    echo "$0: upgrade already running - exit" > /dev/console
    exit 1
fi

#some validation
if [ -f "./fmw_board_type" ]; then
    # cur_board=`factory board | sed y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/ | sed s/-//g | grep -o ^[A-Z]*[0-9]*`
    cur_board=`factory board | sed s/-//g | sed s/.IP//g`
    case "$cur_board"  in
    "TAU8N")        board_type="TAU8N";;
    "TAU8N rev.B")  board_type="TAU8N";;
    esac

    if [ -z "$board_type" ]; then
        echo "UPGRADE FAIL: wrong factory settings"  > /dev/console
        setupgradestatus 2
        exit 1;
    fi

    fmw_type=`cat ./fmw_board_type`
    if [ "$fmw_type" != "$board_type" ]; then
        echo "UPGRADE FAIL: firmware for $fmw_type but board is $cur_board"  > /dev/console
        setupgradestatus 2
        exit 1;
    fi
fi

# md5_cur=`busybox md5sum ./linux.bin | cut -d' ' -f 1`
# md5_img=`cat md5_linux`
# if [ "$md5_cur" != "$md5_img" ]; then
#     echo "UPGRADE FAIL: Incorrect CRC";
#     exit 1;
# fi

#some murders
# killall igmpproxy udpxy

if [ -f /tmp/fw/utils/swupdate ]; then
    FW_PATH="/tmp/fw"
else
    if [ -f /tmp/auto_fw_upgrade/utils/swupdate ]; then
        FW_PATH="/tmp/auto_fw_upgrade"
    else
        if [ -f /tmp/dhcp_fw_upgrade/utils/swupdate ]; then
            FW_PATH="/tmp/dhcp_fw_upgrade"
        else
            FW_PATH="/tmp/fw_tr069"
        fi
    fi
fi


# chmod 777 $FW_PATH/utils/stop_voip
# $FW_PATH/utils/stop_voip
chmod 777 $FW_PATH/utils/swupdate

if [ "$1" != "fw_tr069" ] ; then
    echo "Stopping cwmpClient service" > /dev/console
    systemctl stop cwmpClient > /dev/console
fi

if [ "$1" != "snmp" ] ; then
    echo "Stopping snmpd service" > /dev/console
    killall run_snmpd.sh
    killall snmpd
fi

echo "Stopping VoIP service" > /dev/console
systemctl stop voip > /dev/console
sleep 3
killall voip
sleep 3

# cur_major=$(cat /version|cut -d'.' -f 1)
# cur_minor=$(cat /version|cut -d'.' -f 2)

# if [ $cur_major -eq some ]; then
#     if [ $cur_minor -eq some ]; then
#     fi
# fi

active_slot=$(uenv get active_slot | grep value | cut -b 8)

echo "Upgrade firmware started" > /dev/console
$FW_PATH/utils/swupdate -k swupdate-public.pem -i ./software.swu &> /dev/console
RETVAL=$?

if [ "$RETVAL" != "0" ]; then
    if [ "$RETVAL" = "254" ]; then
        echo "UPGRADE FAIL: upgrade process is already in progress" > /dev/console;
        echo "$0: FATAL ERROR: something is wrong with upgrade flags - multiple scripts are runnung!" > /dev/console;
        exit 2;
    fi
    echo "UPGRADE FAIL: Error at read/write operation" > /dev/console;
    setupgradestatus 2
    # нет смысла в текущей работе железки
    reboot
fi
    
if [ -e "$FW_PATH/defaults/def.yaml" ];then
    echo "UPGRADE : update def.yaml" > /dev/console;
    # somehow save new default cfg
fi

if [ "$active_slot" = "1" ]; then
        uenv set $FW_VERSION_2 $(cat $FW_PATH/version)
    else
        uenv set $FW_VERSION_1 $(cat $FW_PATH/version)
fi

# if successfull update, reset switch bank mechanism
# clean flag switch_slot
# call uenv set to parameter with null value (delete it from env)
uenv set switch_slot

echo "UPGRADE SUCCESSFULL" > /dev/console
setupgradestatus 0
exit 0;

==> tau8n-1.8.2-b34-with-loader.tar.gz: upgrade.sh <==
#!/bin/sh

FW_VERSION_1="fw_version_1"
FW_VERSION_2="fw_version_2"

BIN_SWUPDATE="/usr/bin/swupdate"

#echo 2 > /proc/sys/vm/overcommit_memory
#echo 100 > /proc/sys/vm/overcommit_ratio

echo "Start firmware upgrading"
echo "Start firmware upgrading" > /dev/console


setupgradestatus 1
if [ "$?" != "0" ]; then
    echo "$0: upgrade already running - exit" > /dev/console
    exit 1
fi

#some validation
if [ -f "./fmw_board_type" ]; then
    # cur_board=`factory board | sed y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/ | sed s/-//g | grep -o ^[A-Z]*[0-9]*`
    cur_board=`factory board | sed s/-//g | sed s/.IP//g`
    case "$cur_board"  in
    "TAU8N")        board_type="TAU8N";;
    "TAU8N rev.B")  board_type="TAU8N";;
    esac

    if [ -z "$board_type" ]; then
        echo "UPGRADE FAIL: wrong factory settings"  > /dev/console
        setupgradestatus 2
        exit 1;
    fi

    fmw_type=`cat ./fmw_board_type`
    if [ "$fmw_type" != "$board_type" ]; then
        echo "UPGRADE FAIL: firmware for $fmw_type but board is $cur_board"  > /dev/console
        setupgradestatus 2
        exit 1;
    fi
fi

# md5_cur=`busybox md5sum ./linux.bin | cut -d' ' -f 1`
# md5_img=`cat md5_linux`
# if [ "$md5_cur" != "$md5_img" ]; then
#     echo "UPGRADE FAIL: Incorrect CRC";
#     exit 1;
# fi

#some murders
# killall igmpproxy udpxy

if [ -f /tmp/fw/utils/swupdate ]; then
    FW_PATH="/tmp/fw"
else
    if [ -f /tmp/auto_fw_upgrade/utils/swupdate ]; then
        FW_PATH="/tmp/auto_fw_upgrade"
    else
        if [ -f /tmp/dhcp_fw_upgrade/utils/swupdate ]; then
            FW_PATH="/tmp/dhcp_fw_upgrade"
        else
            FW_PATH="/tmp/fw_tr069"
        fi
    fi
fi


# chmod 777 $FW_PATH/utils/stop_voip
# $FW_PATH/utils/stop_voip
# chmod 777 $FW_PATH/utils/swupdate

if [ "$1" != "fw_tr069" ] ; then
    echo "Stopping cwmpClient service" > /dev/console
    systemctl stop cwmpClient > /dev/console
fi

if [ "$1" != "snmp" ] ; then
    echo "Stopping snmpd service" > /dev/console
    killall run_snmpd.sh
    killall snmpd
fi

echo "Stopping VoIP service" > /dev/console
systemctl stop voip > /dev/console
sleep 3

# cur_major=$(cat /version|cut -d'.' -f 1)
# cur_minor=$(cat /version|cut -d'.' -f 2)

# if [ $cur_major -eq some ]; then
#     if [ $cur_minor -eq some ]; then
#     fi
# fi

active_slot=$(uenv get active_slot | grep value | cut -b 8)

echo "Upgrade firmware started" > /dev/console
$FW_PATH/utils/swupdate -k swupdate-public.pem -i ./software.swu &> /dev/console
RETVAL=$?

if [ "$RETVAL" != "0" ]; then
    if [ "$RETVAL" = "254" ]; then
        echo "UPGRADE FAIL: upgrade process is already in progress" > /dev/console;
        echo "$0: FATAL ERROR: something is wrong with upgrade flags - multiple scripts are runnung!" > /dev/console;
        exit 2;
    fi
    echo "UPGRADE FAIL: Error at read/write operation" > /dev/console;
    setupgradestatus 2
    # нет смысла в текущей работе железки
    reboot
    exit 6;
fi
    
if [ -e "$FW_PATH/defaults/def.yaml" ];then
    echo "UPGRADE : update def.yaml" > /dev/console;
    # somehow save new default cfg
fi

if [ "$active_slot" = "1" ]; then
        uenv set $FW_VERSION_2 $(cat $FW_PATH/version)
    else
        uenv set $FW_VERSION_1 $(cat $FW_PATH/version)
fi

# if successfull update, reset switch bank mechanism
# clean flag switch_slot
# call uenv set to parameter with null value (delete it from env)
uenv set switch_slot

echo "UPGRADE SUCCESSFULL" > /dev/console
setupgradestatus 0
exit 0;
